@@ -83,6 +83,15 @@ def generateFeatures(font, args):
     preprocessor.write(o)
     font.features.text = o.getvalue() + font.features.text
 
+def _groupMarkClasses(self, markGlyphToMarkClasses):
+    markClasses = set()
+    for x in markGlyphToMarkClasses.values():
+        markClasses.update(x)
+    # Sort them
+    return sorted(markClasses, key=lambda x: -self.anchorSortKey.get(self._removeClassPrefix(x), 0))
+
+# Monkey patch MarkFeatureWriter to not do any funny grouping business.
+MarkFeatureWriter._groupMarkClasses = _groupMarkClasses
 
 def generateFont(options, font):
     generateFeatures(font, options)
@@ -97,11 +106,7 @@ def generateFont(options, font):
     info.openTypeNameLicense = "This Font Software is licensed under the SIL Open Font License, Version 1.1. This license is available with a FAQ at: https://scripts.sil.org/OFL"
     info.openTypeNameLicenseURL = "https://scripts.sil.org/OFL"
 
-    markWriter = MarkFeatureWriter(features=["mark", "mkmk"])
-    # ufo2ft mark feature writer decides what feature to use for what glyph
-    # based on script, and it classifies kashida-ar with scripts using abvm
-    # feature and doesn’t add it to mark feature, which is not what we want.
-    markWriter.scriptsUsingAbvm = set()
+    markWriter = MarkFeatureWriter()
 
     # Maintain our desired lookup order.
     markWriter.anchorSortKey = {
@@ -198,7 +203,7 @@ def makeOverLine(font, posGlyph="qafLamAlefMaksuraabove-ar"):
                 widths[width] = []
             widths[width].append(glyph.name)
 
-    base = 'uni0305'
+    base = 'overlinecomb'
     drawOverline(font, base, 0x0305, pos, thickness, 500)
 
     mark = ast.FeatureBlock("mark")
@@ -210,7 +215,7 @@ def makeOverLine(font, posGlyph="qafLamAlefMaksuraabove-ar"):
         # for each width group we create an over/underline glyph with the same
         # width, and add a contextual substitution lookup to use it when an
         # over/underline follows any glyph in this group
-        replace = f"uni0305.{width}"
+        replace = f"overlinecomb.{width}"
         drawOverline(font, replace, None, pos, thickness, width)
         sub = ast.SingleSubstStatement([ast.GlyphName(base)],
                                        [ast.GlyphName(replace)],
@@ -242,7 +247,7 @@ def makeItalic(options):
 
     exclude = [f"u{i:X}" for i in range(0x1EE00, 0x1EEFF + 1)]
     exclude += [
-        "exclam", "period", "guillemotleft", "guillemotright", "braceleft",
+        "exclam", "period", "guillemetleft", "guillemetright", "braceleft",
         "bar", "braceright", "bracketleft", "bracketright", "parenleft",
         "parenright", "slash", "backslash", "brokenbar", "question-ar",
         "dot.1", "dot.2", "zerowidthnonjoiner", "zerowidthjoiner",
@@ -271,7 +276,7 @@ def makeItalic(options):
         info.styleMapStyleName = "italic"
 
     mergeLatin(font)
-    makeOverLine(font, posGlyph="uni0305")
+    makeOverLine(font, posGlyph="overlinecomb")
     otf = generateFont(options, font)
     otf.save(options.output)
 
@@ -455,7 +460,7 @@ def makeCOLR(font):
     )
 
     signs = (
-        "uni0305",
+        "overlinecomb",
         "zero-ar",
         "one-ar",
         "two-ar",
@@ -580,7 +585,7 @@ def _build_production_name(glyph, font):
     return glyph.name
 
 def openFont(path):
-    font = Font.open(path, validate=False)
+    font = Font.open(path)
 
     if REMOVE_GLYPHS in font.lib:
         import re
@@ -601,7 +606,7 @@ def makeDesktop(options, generate=True):
 
     if generate:
         mergeLatin(font)
-        makeOverLine(font, posGlyph="uni0305")
+        makeOverLine(font, posGlyph="overlinecomb")
         otf = generateFont(options, font)
         otf.save(options.output)
     else:
